import path from 'path';
import fs from 'fs';
import { transform } from '@svgr/core';
export default function generateReactSvg({ output, replaceAttrValues, }) {
    return (source) => {
        console.log(source[0].filesInfo[0]);
        const result = source[0].filesInfo
            .filter((it) => {
            return it.ext === '.svg';
        })
            .map((fileInfo) => {
            const svgName = fileInfo.dir.split(path.sep).slice(-1);
            const svgStyle = fileInfo.name;
            // 获取文件名 activity_filled.tsx
            const generatedFileName = `${svgName}_${svgStyle}`;
            // 导出的默认组件名 ActivityFilled
            const exportComponentName = toHump(generatedFileName);
            const svgCode = fs.readFileSync(fileInfo.path, 'utf-8');
            try {
                const jsCode = transform.sync(svgCode, {
                    plugins: [
                        '@svgr/plugin-svgo',
                        '@svgr/plugin-jsx',
                        '@svgr/plugin-prettier',
                    ],
                    icon: true,
                    typescript: true,
                    replaceAttrValues,
                }, { componentName: exportComponentName });
                return {
                    pathname: path.resolve(output, `${generatedFileName}.tsx`),
                    code: jsCode,
                };
            }
            catch (error) {
                console.error(error);
            }
            return [];
        });
        return result;
    };
}
// 下划线转驼峰
function toHump(name) {
    return name
        .split('_')
        .map((it) => {
        return it.replace(/^\w/g, (it) => {
            return it.toUpperCase();
        });
    })
        .join('');
}
//# sourceMappingURL=mod.js.map